<?php


function clean_user_data( $user ) {
	return [
		'ID'           => $user->ID,
		'display_name' => $user->display_name,
		'nickname'     => $user->nickname,
	];
}

$ldpa             = new Learndash_Access_For_Parents();
$existing_parents = get_users( [ 'role__in' => [ 'parent' ] ] );
$existing_parents = array_map( 'clean_user_data', $existing_parents );
// $parents = get_users( [ 'role__not_in' => [ 'student', 'parent' ] ] );
$existing_parents_ids = [];
foreach ( $existing_parents as $existing_parent ) {
	array_push( $existing_parents_ids, $existing_parent['ID'] );
}


$parents               = get_users( [ 'exclude' => $existing_parents_ids ] );
$parents               = array_map( 'clean_user_data', $parents );
$students              = $ldpa->ldpa_get_enrolled_students();
$student_child_records = $ldpa->ldpa_student_child_records();
$nonce                 = wp_create_nonce();
$counter               = 1;
$records               = [];


foreach ( $student_child_records as $record ) {
	if ( ! isset( $records[ $record->parent_id ] ) ) {
		$records[ $record->parent_id ] = [
			'parent' => [
				'id'           => $record->parent_id,
				'display_name' => $record->parent_display_name,
				'nicename'     => $record->parent_nicename,
			],
		];
	}
	$records[ $record->parent_id ]['students'][] = [
		'id'                 => $record->child_id,
		'display_name'       => $record->child_display_name,
		'nicename'           => $record->child_nicename,
		'is_child_confirmed' => $record->is_child_confirmed,
	];
}

?>

<style type="text/css" scoped>
	.select2-container .select2-search--inline .select2-search__field {
		margin-top: 0px;
	}
</style>

<div id="sfwd-header">
</div>
<div class="wrap">
	<h1 class="hidden"><?php _e( 'LearnDash Parent Access', 'learndash-access-for-parents' ); ?></h1>
</div>

<!-- Success Notification -->
<div id="successNotification" class="spald-fixed spald-hidden spald-mt-5 spald-inset-0 spald-flex spald-items-start spald-justify-end spald-px-4 spald-py-6 spald-pointer-events-none spald-sm:p-6 spald-sm:items-start spald-sm:justify-end">
	<div class="spald-max-w-sm spald-w-full spald-bg-white spald-shadow-lg spald-rounded-lg spald-pointer-events-auto">
		<div class="spald-ounded-lg spald-shadow-xs spald-overflow-hidden">
			<div class="spald-p-4">
				<div class="spald-flex spald-items-start">
					<div class="spald-flex-shrink-0">
						<svg  class="spald-mt-2 spald-h-6 spald-w-6 spald-text-green-400" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor">
							<path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M13.828 10.172a4 4 0 00-5.656 0l-4 4a4 4 0 105.656 5.656l1.102-1.101m-.758-4.899a4 4 0 005.656 0l4-4a4 4 0 00-5.656-5.656l-1.1 1.1" />
						</svg>
					</div>
					<div class="spald-ml-3 spald-w-0 spald-flex-1 spald-pt-0.5">
						<p class="spald-text-sm spald-leading-5 spald-font-medium spald-text-gray-900">
							<?php esc_html_e( 'Link created successfully', 'learndash-access-for-parents' ); ?>
						</p>
						<p class="spald-mt-1 spald-text-sm spald-leading-5 spald-text-gray-500">
							<?php esc_html_e( 'Page will reload in few seconds', 'learndash-access-for-parents' ); ?>
						</p>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>

<!-- Delete -->
<div id="deleteNotification" class="spald-fixed spald-hidden spald-mt-5 spald-inset-0 spald-flex spald-items-start spald-justify-end spald-px-4 spald-py-6 spald-pointer-events-none spald-sm:p-6 spald-sm:items-start spald-sm:justify-end">
	<div class="spald-max-w-sm spald-w-full spald-bg-white spald-shadow-lg spald-rounded-lg spald-pointer-events-auto">
		<div class="spald-rounded-lg spald-shadow-xs spald-overflow-hidden">
			<div class="spald-p-4">
				<div class="spald-flex spald-items-start">
					<div class="spald-flex-shrink-0">
						<svg class="spald-mt-2 spald-h-6 spald-w-6 spald-text-red-400" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" fill="currentColor">
							<path fill-rule="evenodd" d="M9 2a1 1 0 00-.894.553L7.382 4H4a1 1 0 000 2v10a2 2 0 002 2h8a2 2 0 002-2V6a1 1 0 100-2h-3.382l-.724-1.447A1 1 0 0011 2H9zM7 8a1 1 0 012 0v6a1 1 0 11-2 0V8zm5-1a1 1 0 00-1 1v6a1 1 0 102 0V8a1 1 0 00-1-1z" clip-rule="evenodd" />
						</svg>
					</div>
					<div class="spald-ml-3 spald-w-0 spald-flex-1 spald-pt-0.5">
						<p class="spald-text-sm spald-leading-5 spald-font-medium spald-text-gray-900">
							<?php esc_html_e( 'Link Deleted successfully', '' ); ?>
						</p>
						<p class="spald-mt-1 spald-text-sm spald-leading-5 spald-text-gray-500">
							<?php esc_html_e( 'Page will reload in few seconds', '' ); ?>
						</p>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>

<!-- Error -->
<div id="errorNotification" class="fixed hidden mt-5 inset-0 flex items-end justify-center px-4 py-6 pointer-events-none sm:p-6 sm:items-start sm:justify-end">
	<div class="max-w-sm w-full bg-white shadow-lg rounded-lg pointer-events-auto">
		<div class="rounded-lg shadow-xs overflow-hidden">
			<div class="p-4">
				<div class="flex items-start">
					<div class="ml-3 w-0 flex-1 pt-0.5">
						<p class="message text-sm leading-5 font-medium text-red-600"></p>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>

<div class="wrap">
	<div class="spald-bg-white spald-overflow-hidden spald-shadow spald-rounded-lg">
		<div class="spald-border-b spald-border-gray-200 spald-px-4 spald-py-5 spald-sm:px-6">
			<h3 class="spald-inline-block spald-text-lg spald-leading-6 spald-font-medium spald-text-gray-900" > <?php _e( 'Manage Parent Access', 'learndash-access-for-parents' ); ?> </h3> 
			<span class="spald-inline-flex spald-rounded-md spald-shadow-sm spald-ml-2">
				<button type="button" id="create-btn" class="spald-inline-flex spald-items-center spald-px-3 spald-py-2 spald-border spald-border-transparent spald-text-sm spald-leading-4 spald-font-medium spald-rounded-md spald-text-white spald-bg-indigo-600 spald-hover:bg-indigo-500 spald-focus:outline-none spald-focus:border-indigo-700 spald-focus:shadow-outline-indigo spald-active:bg-indigo-700 spald-transition spald-ease-in-out spald-duration-150">
					<?php _e( 'Create New Link', 'learndash-access-for-parents' ); ?> 
					<!-- Heroicon name: LINK -->
					<svg  class="spald-ml-2 spald--mr-0.5 spald-h-4 spald-w-4" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor">
						<path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M13.828 10.172a4 4 0 00-5.656 0l-4 4a4 4 0 105.656 5.656l1.102-1.101m-.758-4.899a4 4 0 005.656 0l4-4a4 4 0 00-5.656-5.656l-1.1 1.1" />
					</svg>

				</button>
			</span>

			<div id="linker-container" class="spald-bg-white spald-overflow-hidden spald-shadow spald-rounded-lg spald-mt-5" style="display: none;">
				<form id="data-form">
					<div class="spald-px-4 spald-py-5 spald-sm:p-6">
						<!-- <h3 id="linker-title"></h3> -->
						<div class=" spald-w-1/4 spald-inline-block"> 
							<label for="parents-list" class="spald-block spald-text-sm spald-font-medium spald-leading-5 spald-text-gray-700 spald-mb-2"> <?php _e( 'Parents', 'learndash-access-for-parents' ); ?></label>
							<select name="parents-list" id="parents-list" class="select2-class-selector" style="width: 100%;">
								<?php foreach ( $parents as $parent ) : ?>
									<option value="<?php echo $parent['ID']; ?>"><?php echo $parent['display_name'] . ' (' . $parent['nickname'] . ')'; ?></option>
								<?php endforeach; ?>
							</select>
						</div>

						<div class=" spald-w-3/5 spald-inline-block">
							<label for="students-list" class="spald-block spald-text-sm spald-font-medium spald-leading-5 spald-text-gray-700 spald-mb-2"> <?php _e( 'Students', 'learndash-access-for-parents' ); ?>  </label>
							<select name="students-list[]" id="students-list" class="" multiple="multiple" style="width: 100%;">
								<?php foreach ( $students as $student ) : ?>
									<option value="<?php echo $student->ID; ?>">
										<?php echo $student->display_name . ' (' . $student->nickname . ')'; ?>
									</option>
								<?php endforeach; ?>
							</select>
						</div>

						<div style="margin-top: 20px">
							<span id="link-btn" class="spald-inline-flex spald-rounded-md spald-shadow-sm">
							<button type="submit" class="spald-button spald-inline-flex spald-mr-2 spald-items-center spald-px-4 spald-py-2 spald-border spald-border-blue-300 spald-text-sm spald-leading-5 spald-font-medium spald-rounded-md spald-text-blue-700 spald-bg-white spald-hover:text-blue-500 spald-focus:outline-none spald-focus:border-blue-300 spald-focus:shadow-outline-blue spald-active:text-blue-800 spald-active:bg-blue-50 spald-transition spald-ease-in-out spald-duration-150">
								<?php _e( 'Save', 'learndash-access-for-parents' ); ?> 
							</button>
							<button type="button" id="data-cancel-button" class="spald-button spald-inline-flex spald-items-center spald-px-4 spald-py-2 spald-border spald-border-red-300 spald-text-sm spald-leading-5 spald-font-medium spald-rounded-md spald-text-red-700 spald-bg-white spald-hover:text-red-500 spald-focus:outline-none spald-focus:border-red-300 spald-focus:shadow-outline-blue spald-active:text-red-800 spald-active:bg-red-50 spald-transition spald-ease-in-out spald-duration-150">
								<?php _e( 'Cancel', 'learndash-access-for-parents' ); ?> 
							</button>
							<img src="<?php echo esc_url( plugin_dir_url( dirname( __FILE__ ) ) . 'assets/loader.gif' ); ?>" width="25" height="25" class="gif-loader" style="display: none;">
						</div>
					</div>
				</form>
			</div>
		</div>
		<div class="spald-px-4 spald-py-5 spald-sm:p-6">
			<div class="spald-flex spald-flex-col">
				<div class="spald--my-2 spald-overflow-x-auto spald-sm:-mx-6 spald-lg:-mx-8">
					<div class="spald-py-2 spald-align-middle spald-inline-block spald-min-w-full spald-sm:px-6 spald-lg:px-8">
					<div class="spald-shadow spald-overflow-hidden spald-border-b spald-border-gray-200 spald-sm:rounded-lg">
						<table class="spald-min-w-full spald-divide-y spald-divide-gray-200">
						<thead>
							<tr>
								<th class="spald-px-6 spald-py-3 spald-bg-gray-50 spald-text-left spald-text-xs spald-leading-4 spald-font-medium spald-text-gray-500 spald-uppercase spald-tracking-wider">
									<?php _e( 'Parent', 'learndash-access-for-parents' ); ?> 
								</th>
								<th class="spald-px-6 spald-py-3 spald-bg-gray-50 spald-text-left spald-text-xs spald-leading-4 spald-font-medium spald-text-gray-500 spald-uppercase spald-tracking-wider">
									<?php _e( 'Students', 'learndash-access-for-parents' ); ?> 
								</th>
								<th class="spald-px-6 spald-py-3 spald-bg-gray-50 spald-text-center spald-text-xs spald-leading-4 spald-font-medium spald-text-gray-500 spald-uppercase spald-tracking-wider">
									<?php _e( 'Actions', 'learndash-access-for-parents' ); ?> 
								</th>
							</tr>
						</thead>
						<tbody class="spald-bg-white spald-divide-y spald-divide-gray-200">

							<?php foreach ( $records as $record ) : ?>

								<tr>
									<td class="spald-px-6 spald-py-4 spald-whitespace-no-wrap" data-parent-id="<?php echo $record['parent']['id']; ?>">
										<div class="spald-flex spald-items-center">
											<div class="spald-flex-shrink-0 spald-h-10 spald-w-10">
												<img class="spald-h-10 spald-w-10 spald-rounded-full" src="<?php echo esc_url( get_avatar_url( $record['parent']['id'] ) ); ?>" alt="">
											</div>
											<div class="spald-ml-4">
												<div class="spald-text-sm spald-leading-5 spald-font-medium spald-text-gray-900">
													<?php echo $record['parent']['display_name']; ?>
												</div>
											</div>
										</div>
									</td>
									<td class="spald-px-6 spald-py-4 spald-whitespace-no-wrap">
										<?php foreach ( $record['students'] as $key => $student ) : ?> 
											<div class="spald-text-sm spald-inline-block spald-leading-5 spald-text-gray-900" data-student-id="<?php echo $student['id']; ?>">
												<?php echo $student['display_name']; ?>
												<?php if ( $student['is_child_confirmed'] ) { ?>
													<span class="spald-text-xs spald-text-green-500 spald-italic"><?php _e( '(Account Confirmed)', 'learndash-access-for-parents' ); ?> </span>
												<?php } else { ?>
													<span class="spald-text-xs spald-text-gray-500 spald-italic"><?php _e( '(Pending to Confirm)', 'learndash-access-for-parents' ); ?> </span>
												<?php } ?>
											</div>
											<?php if ( count( $record['students'] ) - 1 !== $key ) { ?>
												<strong> / </strong>
											<?php } ?>
										<?php endforeach; ?>

									</td>
									<td class="spald-px-6 spald-py-4 spald-whitespace-no-wrap spald-text-center spald-text-sm spald-leading-5 spald-font-medium">
										<button type="button" class="spald-button spald-button-no-style edit-btn spald-text-indigo-600 spald-hover:text-indigo-900"> <?php _e( 'Edit', 'learndash-access-for-parents' ); ?>  </button><strong> | </strong>
										<button type="button" class="spald-button spald-button-no-style delete-btn spald-text-indigo-600 spald-hover:text-indigo-900"> <?php _e( 'Delete', 'learndash-access-for-parents' ); ?> </button>
									</td>
								</tr>

							<?php endforeach; ?>
						</tbody>
						</table>
					</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>

<script>
	(function($) {
		const existingParents = <?php echo wp_json_encode( $existing_parents ); ?>;
		const parents = <?php echo wp_json_encode( $parents ); ?>;

		function addErrorMessage(message) {
			const node = document.getElementById('errorNotification');
			const messageNode = node.querySelector('p.message');
			messageNode.innerText = message;
			node.classList.remove('hidden');

			setTimeout(function() {
				node.classList.add('hidden');
			}, 3500);
		}

		function getFormOptions(isEdit = false) {
			return isEdit ? existingParents : parents;
		}

		function setFormOptions(selectElement, newOptions, selected = null, onlySelectOption = false) {
			const options = selectElement.querySelectorAll('option');
			options.forEach(function(option) { option.remove()});

			if (!onlySelectOption) {
				selectElement[selectElement.options.length] = new Option('', '', false, false);
			}

			newOptions.forEach(function(option, key) {
				const isSelected = option['ID'] === selected ? true : false
				if (onlySelectOption && !isSelected) {
					return;
				}
				selectElement[selectElement.options.length] = new Option(option['display_name'] + ' (' + option['nickname'] + ')', option['ID'], isSelected, isSelected);
			});
		}

		var toggleLoading = function(forceHide = false) {
			if (forceHide) {
				$('.gif-loader').hide();
			} else {
				$('.gif-loader').toggle();
			}
		}

		var toggleLinkerSection = function(title) {
			$('#linker-title').text(title);
			$('#linker-container').show();
		}

		$(' #students-list').select2({
			placeholder: '<?php _e( 'Select student user', 'learndash-access-for-parents' ); ?>',
			theme: "classic"
		});

		$(' #parents-list').select2({
			placeholder: '<?php _e( 'Select parent user', 'learndash-access-for-parents' ); ?>'
		});

		$(document).on('click', '#create-btn', function() {
			const selectElement = document.getElementById('parents-list');
			selectElement.removeAttribute('readonly');

			const newOptions = getFormOptions();
			setFormOptions(selectElement, newOptions);

			$('#students-list').val(null).trigger('change');
			toggleLinkerSection('<?php _e( 'New Parent-Student Link', 'learndash-access-for-parents' ); ?>');
		});


		$(document).on('click', '.edit-btn', function() {
			var $tr = $(this).closest('tr');
			var dataParentElement = $tr.find('[data-parent-id]');
			var parentId = $(dataParentElement).data('parent-id');
			var dataStudentsElementsArray = $tr.find('[data-student-id]');
			var studentsId = [];
			$.map(dataStudentsElementsArray, function(element) {
				studentsId.push($(element).data('student-id'));
			});

			const selectElement = document.getElementById('parents-list');
			const newOptions = getFormOptions(true);
			setFormOptions(selectElement, newOptions, parentId, true);
			selectElement.setAttribute('readonly', true);
			$('#students-list').val(studentsId).trigger('change');

			toggleLinkerSection('<?php _e( 'Edit Links to Parent: ', 'learndash-access-for-parents' ); ?> ' + dataParentElement.text());
		});

		// delete existing links
		$(document).on('click', '.delete-btn', function() {
			var linkUrl = '<?php echo admin_url( "admin-ajax.php?action=delete_parent_to_student&nonce={$nonce}" ); ?>';
			var $tr = $(this).closest('tr');
			var dataParentElement = $tr.find('[data-parent-id]');
			var parentId = $(dataParentElement).data('parent-id');
			var dataStudentsElementsArray = $tr.find('[data-student-id]');

			$.ajax({
				method: 'POST',
				url: linkUrl,
				data: {
					nonce: '<?php echo $nonce; ?>',
					parent_id: parentId
				},
				success: function(response) {
					$('#deleteNotification').removeClass('spald-hidden');	
					toggleLoading();

					setTimeout(function() {
						location.reload();
					}, 2500);
				}
			})
		});


		const dataForm = document.getElementById('data-form');
		dataForm.addEventListener('submit', function(event) {
			event.preventDefault();

			try {
				const form = event.target;

				toggleLoading();
				const linkUrl = '<?php echo admin_url( 'admin-ajax.php?action=link_parent_to_student' ); ?>';
				const parentId = form.elements['parents-list'].value;
				const studentId = $('#students-list').val();

				$.ajax({
					method: 'POST',
					url: linkUrl,
					data: {
						nonce: '<?php echo $nonce; ?>',
						parent_id: parentId,
						student_ids: studentId,
					},
					success: function(response) {
						$('#parents-list').val(null).trigger('change');
						$('#students-list').val(null).trigger('change');
						toggleLoading();

						if ('success' === response.status) {
							$('#successNotification').removeClass('spald-hidden');
							setTimeout(function() {
								location.reload();
							}, 2500);
							form.reset();
						} else {
							addErrorMessage(response.message);
							toggleLoading(true);
						}
					},
					error: function(response) {
						addErrorMessage(response.message);
						toggleLoading(true);
					}
				}).catch(err => {
					addErrorMessage(err.message);
					toggleLoading(true);
				});
			} catch (err) {
				addErrorMessage(err.message);
				toggleLoading(true);
			}
		});

		const cancelButton = document.getElementById('data-cancel-button');
		cancelButton.addEventListener('click', function () {
			dataForm.reset();
			$('#linker-container').hide();
		})
	})(jQuery);
</script>
