<?php

/**
 * Fired during plugin activation
 *
 * @link       immerseus.com
 * @since      1.0.0
 *
 * @package    Learndash_Access_For_Parents
 * @subpackage Learndash_Access_For_Parents/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Learndash_Access_For_Parents
 * @subpackage Learndash_Access_For_Parents/includes
 * @author     Immerseus <dnyaneshmahajan12@gmail.com>
 */
class Learndash_Access_For_Parents_Activator {

	/**
	 * Short Description. (use period)
	 *
	 * Long Description.
	 *
	 * @since    1.0.0
	 */

	public static function activate() {
		$are_roles_set = get_option( 'ldap_roles_are_set' );
		$capabilities  = get_role( 'subscriber' )->capabilities;

		if ( ! $are_roles_set ) {
			add_role( 'parent', 'Parent', $capabilities );
			add_role( 'child', 'Student', $capabilities );
			update_option( 'ldap_roles_are_set', true );
		} else {

			$parent_role = get_role( 'parent' );
			foreach ( $capabilities as $cap => $value ) {
				$parent_role->add_cap( $cap, $value );
			}

			$child_role = get_role( 'child' );
			foreach ( $capabilities as $cap => $value ) {
				$child_role->add_cap( $cap, $value );
			}
		}
		self::ldpa_create_table();
	}

	public static function ldpa_create_table() {

		global $wpdb;
		$table_name      = $wpdb->prefix . 'ldap_child_parent';
		$charset_collate = $wpdb->get_charset_collate();

		$sql = "CREATE TABLE IF NOT EXISTS {$table_name} (
					id int(11) NOT NULL AUTO_INCREMENT,
					parent_id int(11) NOT NULL, 
					child_id int(11) NOT NULL,
					is_child_confirmed TINYINT(1) DEFAULT 0 NOT NULL,
					child_confirmed_at datetime DEFAULT NULL,
					INDEX parent_id (parent_id),
					INDEX child_id (child_id),
					PRIMARY KEY  (id)
				) $charset_collate;";

		// Create table for parent child course link
		$table_name_course_link = $wpdb->prefix . 'ldap_course_link';
		$charset_collate        = $wpdb->get_charset_collate();

		$sql_course_link = "CREATE TABLE IF NOT EXISTS {$table_name_course_link} (
					id int(11) NOT NULL AUTO_INCREMENT,
					parent_id int(11) NOT NULL, 
					child_id int(11) NOT NULL,
					course_id int(11) NOT NULL,
					order_id int(11) NOT NULL,
					link_date datetime DEFAULT CURRENT_TIMESTAMP,
					INDEX parent_id (parent_id),
					INDEX child_id (child_id),
					INDEX course_id (course_id),
					INDEX order_id (order_id),
					PRIMARY KEY  (id)
				) $charset_collate;";

		// Create table for parent child course link
		$table_name_course_vault = $wpdb->prefix . 'ldap_course_storage';
		$charset_collate         = $wpdb->get_charset_collate();

		$sql_course_vault = "CREATE TABLE IF NOT EXISTS {$table_name_course_vault} (
					id int(11) NOT NULL AUTO_INCREMENT,
					parent_id int(11) NOT NULL, 
					course_id int(11) NOT NULL,
					order_id int(11) NOT NULL,
					INDEX parent_id (parent_id),
					INDEX course_id (course_id),
					INDEX order_id (order_id),
					PRIMARY KEY  (id)
				) $charset_collate;";

		require_once ABSPATH . 'wp-admin/includes/upgrade.php';
		dbDelta( $sql );
		dbDelta( $sql_course_link );
		dbDelta( $sql_course_vault );

		self::alter_table();

		update_option( 'ldpm_db_version', LEARNDASH_ACCESS_FOR_PARENTS_VERSION );

	}

	private static function alter_table() {
		global $wpdb;
		$ldap_child_parent_table_name = $wpdb->prefix . 'ldap_child_parent';

		$child_confirm_changes = $wpdb->get_results(
			$wpdb->prepare(
				"SELECT COLUMN_NAME
					FROM INFORMATION_SCHEMA.COLUMNS
					WHERE table_name = %s
					AND column_name = 'is_child_confirmed';",
				$ldap_child_parent_table_name
			)
		);

		if ( empty( $child_confirm_changes ) ) {
			$wpdb->query(
				"ALTER TABLE {$ldap_child_parent_table_name}
					ADD child_confirmed_at datetime DEFAULT NULL AFTER child_id,
					ADD COLUMN is_child_confirmed TINYINT(1) DEFAULT 0 NOT NULL AFTER child_id"
			);

		}
	}

}
