<?php

if ( ! defined( 'ABSPATH' ) ) {
	die( 'You can not access this file!' );
}

if ( ! class_exists( 'Learndash_Access_For_Parents_Child_Confirmation_Endpoint' ) ) {
	class Learndash_Access_For_Parents_Child_Confirmation_Endpoint {

		public function __construct() {
			add_action( 'rest_api_init', [ $this, 'register_rest_endpoint' ] );
		}

		/**
		 * Returns the rendered message with the replacements
		 *
		 * @param WP_REST_Request $data .
		 * @return Redirect|WP_Error
		 */
		public function confirm_link( $data ) {
			$overwritten_redirect = Learndash_Access_For_Parents_Mail_Settings::get_option_value( 'redirect' );
			$redirect             = empty( $overwritten_redirect ) ? '/' : $overwritten_redirect;
			try {

				if ( empty( $data['confirm_key'] ) ) {
					return new WP_Error( 'invalid_param', esc_html__( 'Param confirm_key is required.', 'learndash-access-for-parents' ), [ 'status' => 400 ] );
				}

				$decoded = $this->decode_confirm_key( $data['confirm_key'] );

				if ( false === get_userdata( $decoded['child_id'] ) || false === get_userdata( $decoded['parent_id'] ) ) {
					return new WP_Error( 'invalid_data', esc_html__( 'The data is corrupted.', 'learndash-access-for-parents' ), [ 'status' => 400 ] );
				}

				// $decoded = $this->decode_confirm_key( $data['confirm_key'] );
				$this->update_confirmation_in_database( $decoded['child_id'], $decoded['parent_id'] );

				// Redirect to some page... default homepage?
				wp_redirect( get_site_url( null, $redirect . '?success=true&message="Account Successfully linked"' ) );
				exit;
			} catch ( \Exception $ex ) {
				wp_redirect( get_site_url( null, $redirect . "?success=false&message=\"{$ex->getMessage()}\"" ) );
				exit;
			}
		}

		private function update_confirmation_in_database( $child_id, $parent_id ) {
			global $wpdb;

			$table_name = $wpdb->prefix . 'ldap_child_parent';

			$row = $wpdb->get_row( $wpdb->prepare( "SELECT is_child_confirmed FROM $table_name WHERE child_id = %d AND parent_id = %d", $child_id, $parent_id ) );

			if ( $row->is_child_confirmed ) {
				throw new Exception( 'Account is already linked' );
			}

			$wpdb->update(
				$table_name,
				[
					'is_child_confirmed' => 1,
					'child_confirmed_at' => current_time( 'mysql', 1 ),
				],
				[
					'child_id'  => $child_id,
					'parent_id' => $parent_id,
				],
				[
					'%d',
					'%s',
				],
				[
					'%d',
					'%d',
				]
			);
		}

		protected function decode_confirm_key( $key ) {
			$decoded = base64_decode( $key );
			$json    = json_decode( $decoded, true );
			return $json;
		}

		public function validate_key( $param, $request, $key ) {
			$result = $this->decode_confirm_key( $param );

			return ! empty( $result['child_id'] ) && ! empty( $result['parent_id'] ) && isset( $result['email_confirmation'] ) && $result['email_confirmation'];
		}

		public function register_rest_endpoint() {
			register_rest_route(
				'immerseus/v1',
				'/child-confirmation',
				[
					'methods'             => WP_REST_Server::READABLE,
					'callback'            => [ $this, 'confirm_link' ],
					'args'                => [
						'confirm_key' => [
							'validate_callback' => [ $this, 'validate_key' ],
						],
					],
					'permission_callback' => '__return_true',
				]
			);
		}
	}
}

// Registers the endpoint.
new Learndash_Access_For_Parents_Child_Confirmation_Endpoint();
