<?php

/**
 * Class that handles the registration for parents
 *
 * @link       immerseus.com
 * @since      1.0.0
 *
 * @package    Learndash_Access_For_Parents
 * @subpackage Learndash_Access_For_Parents/Registration
 */

class Learndash_Access_For_Parents_Registration {

	public function __construct() {
		add_action( 'register_form', [ $this, 'add_registration_checkbox' ] );
		add_action( 'user_register', [ $this, 'save_registration' ] );

		add_action( 'woocommerce_after_checkout_registration_form', [ $this, 'add_parent_field_to_register_form' ] );
		add_action( 'woocommerce_register_form', [ $this, 'add_parent_field_to_register_form' ] );
	}

	/**
	 * Adds a checkbox below the registration form
	 */
	public function add_registration_checkbox() {
		?>
		<p class="register-parent">
			<label><input name="user_register_parent" type="checkbox" id="user_register_parent" value="1"> <?php esc_html_e( 'Register as Parent', 'learndash-access-for-parents' ); ?></label>
		</p>
		<?php
	}

	/**
	 * @param (int) $user_id The new user-id of created user
	 */

	public function save_registration( $user_id ) {
		if ( isset( $_POST['user_register_parent'] ) && $_POST['user_register_parent'] == 1 ) {
			$parent = get_user_by( 'id', $user_id );
			$parent->add_role( 'parent' );
			$parent->remove_role( 'subscriber' );
		}

	}

	/**
	 * Implementation on WooCommerce
	 *
	 * @return void
	 */
	public static function add_parent_field_to_register_form() {
		if ( get_option( 'ldpa_allow_woocommerce_to_register_as_parent', 0 ) ) {
			?>
			<p class="form-row form-row-wide create-account">
				<label class="woocommerce-form__label woocommerce-form__label-for-checkbox checkbox">
					<input class="woocommerce-form__input woocommerce-form__input-checkbox input-checkbox" id="user_register_parent" type="checkbox" name="user_register_parent" value="1" /> <span><?php esc_html_e( 'Register as Parent', 'learndash-access-for-parents' ); ?></span>
				</label>
			</p>
			<?php
		}
	}
}

$Learndash_Access_For_Parents_Registration = new Learndash_Access_For_Parents_Registration();
