<?php

/**
 * Class that handles the WooCommerce Integration
 *
 * @link       immerseus.com
 * @since      1.0.0
 *
 * @package    Learndash_Access_For_Parents_WooCommerce
 * @subpackage Learndash_Access_For_Parents_WooCommerce
 */

class Learndash_Access_For_Parents_WooCommerce {

	public function __construct() {
		add_action( 'woocommerce_order_status_completed', array( $this, 'add_course_access' ), 10, 1 );

		add_action( 'woocommerce_order_status_processing', array( $this, 'remove_course_access' ), 10, 1 );
		add_action( 'woocommerce_order_status_refunded', array( $this, 'remove_course_access' ), 10, 1 );
		add_action( 'woocommerce_order_status_cancelled', array( $this, 'remove_course_access' ), 10, 1 );
		add_action( 'woocommerce_order_status_failed', array( $this, 'remove_course_access' ), 10, 1 );
		add_action( 'woocommerce_order_status_on-hold', array( $this, 'remove_course_access' ), 10, 1 );
		add_action( 'woocommerce_order_status_pending', array( $this, 'remove_course_access' ), 10, 1 );
	}

	public static function add_course_access( $order_id ) {
		$order = wc_get_order( $order_id );

		if ( $order !== false ) {
			/**
			 * Only get items for non-subscription products
			 *
			 * @see Learndash_WooCommerce::filter_subscription_products_out() Filter subscription products out when getting items for course access update
			 * @var array
			 */
			$products = $order->get_items();

			$courses_count = 0;
			$groups_count  = 0;
			$courses_ids   = array();
			array_walk(
				$products,
				function( $product ) use ( &$courses_count, &$groups_count ) {
					if ( isset( $product['variation_id'] ) && ! empty( $product['variation_id'] ) ) {
						$courses = (array) get_post_meta( $product['variation_id'], '_related_course', true );
						$groups  = (array) get_post_meta( $product['variation_id'], '_related_group', true );
					} else {
						$courses = (array) get_post_meta( $product['product_id'], '_related_course', true );
						$groups  = (array) get_post_meta( $product['product_id'], '_related_group', true );
					}

					$courses_count += count( $courses );
					$groups_count  += count( $groups );
				}
			);

			foreach ( $products as $product ) {
				$quantity = $product->get_quantity();

				for ( $q = 1; $q <= $quantity; $q++ ) {
					if ( isset( $product['variation_id'] ) && ! empty( $product['variation_id'] ) ) {
						$courses_id    = (array) get_post_meta( $product['variation_id'], '_related_course', true );
						$groups_id     = (array) get_post_meta( $product['variation_id'], '_related_group', true );
						$courses_ids[] = $courses_id;
					} else {
						$courses_id    = (array) get_post_meta( $product['product_id'], '_related_course', true );
						$groups_id     = (array) get_post_meta( $product['product_id'], '_related_group', true );
						$courses_ids[] = $courses_id;
					}

					if ( $courses_ids && is_array( $courses_id ) ) {
						foreach ( $courses_id as $cid ) {
							self::add_courses_to_vault( $order->get_user_id(), $cid, $order_id );
						}
					}

					if ( $groups_id && is_array( $groups_id ) ) {
						foreach ( $groups_id as $group_id ) {

						}
					}
				}
			}
		}
	}

	public static function remove_course_access( $order_id ) {
		$order = wc_get_order( $order_id );

		if ( $order !== false ) {
			/**
			 * Only get items for non-subscription products
			 *
			 * @see Learndash_WooCommerce::filter_subscription_products_out() Filter subscription products out when getting items for course access update
			 * @var array
			 */
			$products = $order->get_items();

			$courses_count = 0;
			$groups_count  = 0;
			$courses_ids   = array();
			array_walk(
				$products,
				function( $product ) use ( &$courses_count, &$groups_count ) {
					if ( isset( $product['variation_id'] ) && ! empty( $product['variation_id'] ) ) {
						$courses = (array) get_post_meta( $product['variation_id'], '_related_course', true );
						$groups  = (array) get_post_meta( $product['variation_id'], '_related_group', true );
					} else {
						$courses = (array) get_post_meta( $product['product_id'], '_related_course', true );
						$groups  = (array) get_post_meta( $product['product_id'], '_related_group', true );
					}

					$courses_count += count( $courses );
					$groups_count  += count( $groups );
				}
			);

			foreach ( $products as $product ) {
				$quantity = $product->get_quantity();

				for ( $q = 1; $q <= $quantity; $q++ ) {
					if ( isset( $product['variation_id'] ) && ! empty( $product['variation_id'] ) ) {
						$courses_id    = (array) get_post_meta( $product['variation_id'], '_related_course', true );
						$groups_id     = (array) get_post_meta( $product['variation_id'], '_related_group', true );
						$courses_ids[] = $courses_id;
					} else {
						$courses_id    = (array) get_post_meta( $product['product_id'], '_related_course', true );
						$groups_id     = (array) get_post_meta( $product['product_id'], '_related_group', true );
						$courses_ids[] = $courses_id;
					}

					if ( $courses_ids && is_array( $courses_id ) ) {
						foreach ( $courses_id as $cid ) {
							self::remove_courses_to_vault( $order->get_user_id(), $cid, $order_id );
						}
					}

					if ( $groups_id && is_array( $groups_id ) ) {
						foreach ( $groups_id as $group_id ) {

						}
					}
				}
			}
		}
	}

	private static function add_courses_to_vault( $parent_id, $course_id, $order_id ) {
		global $wpdb;
		$table_name_course_vault = $wpdb->prefix . 'ldap_course_storage';

		$data   = array(
			'parent_id' => $parent_id,
			'course_id' => $course_id,
			'order_id'  => $order_id,
		);
		$format = array( '%d', '%d', '%d' );
		$wpdb->insert( $table_name_course_vault, $data, $format );
	}

	private static function remove_courses_to_vault( $parent_id, $course_id, $order_id ) {
		global $wpdb;
		$table_name_course_vault = $wpdb->prefix . 'ldap_course_storage';

		$data   = array(
			'parent_id' => $parent_id,
			'course_id' => $course_id,
			'order_id'  => $order_id,
		);
		$format = array( '%d', '%d', '%d' );
		$wpdb->delete( $table_name_course_vault, $data, $format );
	}

}

$Learndash_Access_For_Parents_WooCommerce = new Learndash_Access_For_Parents_WooCommerce();
