<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              honorswp.com
 * @since             1.0.0
 * @package           Learndash_Access_For_Parents
 *
 * @wordpress-plugin
 * Plugin Name:       Student Parent Access for LearnDash
 * Plugin URI:        https://honorswp.com/
 * Description:       Learndash access for parents is plugin for check the progress of their children.
 * Version:           3.2.1
 * Author:            HonorsWP
 * Author URI:        https://honorswp.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       learndash-access-for-parents
 * Domain Path:       /languages
 */

// namespace EA_PARENT_STUDENT_ACC;

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

require_once __DIR__ . '/vendor/autoload.php';

use EA\Licensing\License;

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'LEARNDASH_ACCESS_FOR_PARENTS_VERSION', '3.2.1-beta' );

define( 'LEARNDASH_ACCESS_FOR_PARENTS_DIR', plugin_dir_path( __FILE__ ) );

/**
 * Licensing.
 */
new License(
	'Student Parent Access for LearnDash',
	6602,
	'student-parent-access-for-learndash',
	__FILE__,
	LEARNDASH_ACCESS_FOR_PARENTS_VERSION
);

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-learndash-access-for-parents-activator.php
 */
function activate_learndash_access_for_parents() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-learndash-access-for-parents-activator.php';
	Learndash_Access_For_Parents_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-learndash-access-for-parents-deactivator.php
 */
function deactivate_learndash_access_for_parents() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-learndash-access-for-parents-deactivator.php';
	Learndash_Access_For_Parents_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_learndash_access_for_parents' );
register_deactivation_hook( __FILE__, 'deactivate_learndash_access_for_parents' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-learndash-access-for-parents.php';

require plugin_dir_path( __FILE__ ) . 'includes/class-learndash-access-for-parents-email-sender.php';

require plugin_dir_path( __FILE__ ) . 'includes/class-learndash-access-for-parents-child-confirmation-mailer.php';

require plugin_dir_path( __FILE__ ) . 'admin/partials/class-learndash-access-for-parents-mail-settings.php';

require_once plugin_dir_path( __FILE__ ) . 'includes/class-learndash-access-for-parents-child-confirmation-endpoint.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_learndash_access_for_parents() {

	$plugin = new Learndash_Access_For_Parents();
	$plugin->run();

}
run_learndash_access_for_parents();

/**
 * Require WooCommerce Integration
 */

require plugin_dir_path( __FILE__ ) . 'includes/class-learndash-access-for-parents-woocommerce.php';

// require_once dirname( __FILE__ ) . '/vendor/immerseus/immerseus-upgrader/src/index.php';
