<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       immerseus.com
 * @since      1.0.0
 *
 * @package    Learndash_Access_For_Parents
 * @subpackage Learndash_Access_For_Parents/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Learndash_Access_For_Parents
 * @subpackage Learndash_Access_For_Parents/public
 * @author     Immerseus <dnyaneshmahajan12@gmail.com>
 */
class Learndash_Access_For_Parents_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of the plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Learndash_Access_For_Parents_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Learndash_Access_For_Parents_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name . '-student-link', plugin_dir_url( __FILE__ ) . 'css/spald-student-link-shortcode.css', [], time(), 'all' );
		wp_enqueue_style( $this->plugin_name . '-parent-shortcode', plugin_dir_url( __FILE__ ) . 'css/spald-parent-shortcode.css', [], time(), 'all' );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Learndash_Access_For_Parents_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Learndash_Access_For_Parents_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_register_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/learndash-access-for-parents-public.js', [ 'jquery' ], $this->version, false );
		wp_register_script( $this->plugin_name . '-student-link', plugin_dir_url( __FILE__ ) . 'js/learndash-access-for-parents-links-public.js', [ 'jquery' ], time(), false );
		wp_register_script( $this->plugin_name . '-parent-shortcode', plugin_dir_url( __FILE__ ) . 'js/spald-parent-shortcode.js', [], $this->version, false );

		wp_localize_script(
			$this->plugin_name,
			'spald',
			[ 'ajax_url' => admin_url( 'admin-ajax.php' ) ]
		);
	}


	public function ldpa_register_shortcode() {
		add_shortcode( 'ldpa_page', [ $this, 'ldpa_parent_report_callback' ] );
		add_shortcode( 'parent_access', [ $this, 'ldpa_parent_report_callback' ] );
		add_shortcode( 'ldpa-link-accounts', [ $this, 'ldpa_link_account_callback' ] );
		add_shortcode( 'ldpa_link_accounts', [ $this, 'ldpa_link_account_callback' ] );
	}

	public function ldpa_parent_report_callback( $atts ) {
		if ( ! is_user_logged_in() ) {
			return '<p>' . __( 'Please login to access this page', 'learndash-access-for-parents' ) . '</p>';
		}
		wp_enqueue_style( $this->plugin_name . '-parent-shortcode' );
		wp_enqueue_script( $this->plugin_name . '-parent-shortcode' );

		$current_user = wp_get_current_user();
		$ldpa         = new Learndash_Access_For_Parents();

		$students = $ldpa->ldpa_get_current_user_children( $current_user->ID );

		if ( 0 === count( $students ) ) {
			return '<p>' . __( 'You don\'t have any associated child accounts', 'learndash-access-for-parents' ) . '</p>';
		}

		$output = null;
		ob_start();
		include LEARNDASH_ACCESS_FOR_PARENTS_DIR . 'public/partials/spald-public-parent-access-shortcode-display.php';
		$output .= ob_get_contents();
		ob_end_clean();
		return $output;
	}

	function ldpa_link_account_callback( $shortcode_atts ) {
		if ( ! is_user_logged_in() ) {
			return '<p>' . __( 'Please login to access this page', 'learndash-access-for-parents' ) . '</p>';
		}

		wp_enqueue_style( $this->plugin_name . '-student-link' );
		wp_enqueue_script( $this->plugin_name . '-student-link' );
		$current_user  = wp_get_current_user();
		$user_id       = $current_user->ID;
		$allowed_roles = [ 'administrator', 'parent' ];

		if ( isset( $_POST['ld-submit-links-button'] ) ) {
			$this->ldpa_submit_link_post( $_POST, $user_id );
		}

		if ( isset( $_POST['ld-submit-no-email-account-button'] ) ) {
			$this->ldpa_submit_no_email_account( $_POST, $current_user );
			unset( $_POST );
		}

		if ( isset( $_POST['ld-delete-links-button'] ) ) {
			$this->ldpa_delete_link_post( $_POST, $user_id );
		}

		if ( isset( $_POST['link-parent-course-button'] ) ) {
			$this->ldpa_parent_link_course( $_POST, $user_id );
		}

		if ( isset( $_POST['ld-resend-confirmation-mail-submit'] ) ) {
			$this->ldpa_resend_confirmation_email( $_POST, $user_id );
		}

		$ldpa     = new Learndash_Access_For_Parents();
		$students = $ldpa->ldpa_get_current_user_children( get_current_user_id() );

		$allowed_to_create_accounts_without_email = get_option( 'ldpa_allow_parents_to_create_accounts_without_email', 0 );

		$output = null;
		ob_start();
		include LEARNDASH_ACCESS_FOR_PARENTS_DIR . 'public/partials/spald-public-link-account-shortcode-display.php';
		$output .= ob_get_contents();
		ob_end_clean();
		return $output;
	}

	function ldpa_submit_link_post( $post, $parent_id ) {
		if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'ld-submit-links' ) ) {
			echo '<p>' . __( 'Did not save because your form seemed to be invalid. Sorry', 'learndash-access-for-parents' ) . '</p>';
			return;
		}

		if ( empty( $_POST['link_child_email'] ) ) {
			exit( __( 'Error', 'learndash-access-for-parents' ) );
		}

		if ( isset( $_POST['link_child_email'] ) ) {
			$email = sanitize_email( $_POST['link_child_email'] );
			$user  = get_user_by( 'email', $email );
			if ( $user ) {
				$is_parent = in_array( 'parent', $user->roles, true );

				if ( $is_parent ) {
					$this->message( __( 'Oops! Parent\'s can\'t be linked. You can only link student accounts to a parent.', 'learndash-access-for-parents' ) );
					return;
				}

				$studentIds = [ $user->ID ];
				global $wpdb;
				$table = $wpdb->prefix . 'ldap_child_parent';
				$exist = $wpdb->get_results( "SELECT child_id FROM {$table} WHERE child_id = {$user->ID} LIMIT 1", ARRAY_N );
				if ( $exist ) {
					$this->message( __( 'This email is already linked.', 'learndash-access-for-parents' ) );
				} else {
					$data   = [
						'parent_id' => $parent_id,
						'child_id'  => $user->ID,
					];
					$format = [ '%d', '%d' ];
					$wpdb->insert( $table, $data, $format );
					try {
						$mailer = new Learndash_Access_For_Parents_Child_Confirmation_Mailer( $user, get_userdata( $parent_id ) );
						$mailer->send();
						$this->message( __( 'A confirmation email was sent to verify the account link.', 'learndash-access-for-parents' ), 'green' );
					} catch ( \Exception $err ) {
						$this->message( __( 'Something happened while sending the email. ', 'learndash-access-for-parents' ) . $err->getMessage() . '.', 'red' );
					}
					unset( $_POST );
				}
			} else {
				$this->message( __( 'Invalid email address, Please double check email.', 'learndash-access-for-parents' ) );
			}
		}

	}

	function ldpa_submit_no_email_account( $post, $parent ) {
		global $wpdb;
		if ( ! wp_verify_nonce( $post['_wpnonce'], 'ld-submit-no-email-account' ) ) {
			echo '<p>' . __( 'Did not save because your form seemed to be invalid. Sorry', 'learndash-access-for-parents' ) . '</p>';
			return;
		}

		$username   = isset( $post['username'] ) ? sanitize_text_field( wp_unslash( $post['username'] ) ) : '';
		$password   = isset( $post['password'] ) ? sanitize_text_field( wp_unslash( $post['password'] ) ) : '';
		$first_name = isset( $post['first_name'] ) ? sanitize_text_field( wp_unslash( $post['first_name'] ) ) : '';
		$last_name  = isset( $post['last_name'] ) ? sanitize_text_field( wp_unslash( $post['last_name'] ) ) : '';

		if ( ( empty( $username ) && validate_username( $username ) ) || empty( $password ) || empty( $first_name ) || empty( $last_name ) ) {
			$this->message( __( 'The fields "First Name", "Last Name", "Username" and "Password" are required.', 'learndash-access-for-parents' ) );
			return;
		}

		$child_email = preg_replace( '/([^@]+)(@.+$)/', "$1+{$username}$2", $parent->user_email );
		$child_role  = 'child';

		$existing_child_user = get_user_by( 'email', $child_email );

		if ( $existing_child_user ) {
			$this->message( __( "The child already exists under username {$username}.", 'learndash-access-for-parents' ) );
			return;
		}

		$new_child_id = wp_insert_user(
			[
				'first_name' => $first_name,
				'last_name'  => $last_name,
				'user_pass'  => $password,
				'user_login' => $username,
				'user_email' => $child_email,
				'role'       => $child_role,
			]
		);

		$table         = $wpdb->prefix . 'ldap_child_parent';
		$link_relation = $wpdb->get_results( "SELECT child_id FROM {$table} WHERE child_id = {$new_child_id} LIMIT 1", ARRAY_N );
		$data          = [
			'parent_id'          => $parent->ID,
			'child_id'           => $new_child_id,
			'is_child_confirmed' => 1,
			'child_confirmed_at' => current_time( 'mysql', 1 ),
		];
		$format        = [ '%d', '%d', '%d', '%s' ];
		$wpdb->insert( $table, $data, $format );
		$this->message( __( 'New child account successfully created', 'learndash-access-for-parents' ), 'green' );
	}

	function ldpa_unlink_child_course( $post, $parent_id ) {
		if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'ld-unlink-course' ) ) {
			echo '<p>' . __( 'Did not save because your form seemed to be invalid. Sorry', 'learndash-access-for-parents' ) . '</p>';
			return;
		}

		if ( empty( $_POST['course_id'] ) || empty( $_POST['parent_id'] ) || empty( $_POST['child_id'] ) ) {
			exit( __( 'Error', 'learndash-access-for-parents' ) );
		}

		if ( isset( $_POST['course_id'] ) || isset( $_POST['parent_id'] ) || isset( $_POST['child_id'] ) ) {
			$child_id = (int) $_POST['child_id'];
			$user     = get_user_by( 'id', $child_id );
			if ( $user ) {
				// remove the user from the course
			} else {
				$this->message( __( 'Invalid email address, Please double check email.', 'learndash-access-for-parents' ) );
			}
		}

	}

	function ldpa_delete_link_post( $post, $parent_id ) {
		if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'ld-remove-links' ) ) {
			echo '<p>' . __( 'Did not save because your form seemed to be invalid. Sorry', 'learndash-access-for-parents' ) . '</p>';
			return;
		}

		if ( empty( $_POST['linked_child_id'] ) ) {
			exit( __( 'Error', 'learndash-access-for-parents' ) );
		}

		if ( isset( $_POST['linked_child_id'] ) ) {
			global $wpdb;
			$table        = $wpdb->prefix . 'ldap_child_parent';
			$child_id     = (int) sanitize_title( $_POST['linked_child_id'] );
			$child_detail = get_user_by( 'id', $child_id );
			$wpdb->query(
				$wpdb->prepare(
					"
                        DELETE FROM {$table}
                        WHERE parent_id = %d
                        AND child_id = %s
                    ",
					$parent_id,
					$child_id
				)
			);
			$this->message( $child_detail->user_email . __( ' successfully removed.', 'learndash-access-for-parents' ), 'green' );
			unset( $_POST );
		}

	}


	function ldpa_resend_confirmation_email( $post, $parent_id ) {
		if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'ld-resend-confirmation-mail' ) ) {
			echo '<p>' . __( 'Did not save because your form seemed to be invalid. Sorry', 'learndash-access-for-parents' ) . '</p>';
			return;
		}

		if ( empty( $_POST['linked_child_id'] ) ) {
			exit( __( 'Error', 'learndash-access-for-parents' ) );
		}

		if ( isset( $_POST['linked_child_id'] ) ) {
			try {

				$mailer = new Learndash_Access_For_Parents_Child_Confirmation_Mailer(
					get_userdata( $post['linked_child_id'] ),
					get_userdata( $parent_id )
				);
				$mailer->send();
				$this->message( __( 'Email has been resent', 'learndash-access-for-parents' ), 'green' );
			} catch ( \Exception $err ) {
				$this->message( __( 'Something happened while sending the email. ', 'learndash-access-for-parents' ) . $err->getMessage() . '.', 'red' );
			}
			unset( $_POST );
		}

	}

	/**
	 * @param (obj) $post
	 * @param (int) $parent_id
	 * @return string
	 */
	function ldpa_parent_link_course( $post, $parent_id ) {
		if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'link-parent-course' ) ) {
			echo '<p>' . __( 'Did not save because your form seemed to be invalid. Sorry', 'learndash-access-for-parents' ) . '</p>';
			return;
		}

		if ( empty( $_POST['course_id'] ) ) {
			exit( __( 'Error', 'learndash-access-for-parents' ) );
		}

		if ( empty( $_POST['ldap_link_parent_course_child'] ) ) {
			exit( __( 'Error no child selected', 'learndash-access-for-parents' ) );
		}

		if ( isset( $_POST['course_id'] ) && ! empty( $_POST['ldap_link_parent_course_child'] ) ) {
			if ( sfwd_lms_has_access( $_POST['course_id'], $parent_id ) && ! sfwd_lms_has_access( $_POST['course_id'], $_POST['ldap_link_parent_course_child'] ) ) {
				$child_id  = (int) $_POST['ldap_link_parent_course_child'];
				$course_id = (int) $_POST['course_id'];
				global $wpdb;
				$table_name_course_link = $wpdb->prefix . 'ldap_course_link';

				$exist = $wpdb->get_results( "SELECT parent_id, child_id, course_id FROM {$table_name_course_link} WHERE parent_id = {$parent_id} AND child_id = {$child_id} AND course_id = {$course_id} LIMIT 1", ARRAY_N );
				if ( ! $exist ) {
					ld_update_course_access( $parent_id, $course_id, true );
					ld_update_course_access( $child_id, $course_id, false );

					$data   = [
						'parent_id' => $parent_id,
						'child_id'  => $child_id,
						'course_id' => $course_id,
					];
					$format = [ '%d', '%d' ];
					$wpdb->insert( $table_name_course_link, $data, $format );
					$this->message( __( 'Course has been link successfully', 'learndash-access-for-parents' ), 'green' );
					unset( $_POST );
				}
			} elseif ( $this->ldap_has_course_access( $parent_id, $_POST['course_id'] ) ) {
				$child_id   = (int) $_POST['ldap_link_parent_course_child'];
				$course_id  = (int) $_POST['course_id'];
				$storage_id = (int) $_POST['storage_id'];
				$order_id   = (int) $_POST['order_id'];

				global $wpdb;
				$table_name_course_link    = $wpdb->prefix . 'ldap_course_link';
				$table_name_course_storage = $wpdb->prefix . 'ldap_course_storage';

				$exist = $wpdb->get_results( "SELECT parent_id, child_id, course_id FROM {$table_name_course_link} WHERE parent_id = {$parent_id} AND child_id = {$child_id} AND course_id = {$course_id} LIMIT 1", ARRAY_N );
				if ( ! $exist ) {
					ld_update_course_access( $child_id, $course_id, false );

					$data   = [
						'parent_id' => $parent_id,
						'child_id'  => $child_id,
						'course_id' => $course_id,
						'order_id'  => $order_id,
					];
					$format = [ '%d', '%d', '%d', '%d' ];
					$wpdb->insert( $table_name_course_link, $data, $format );

					$wpdb->delete( $table_name_course_storage, [ 'id' => $storage_id ] );

					$this->message( __( 'Course has been link successfully', 'learndash-access-for-parents' ), 'green' );
					unset( $_POST );
				}
			}
		}

	}

	/**
	 *   Get all the linked courses of a parent
	 *
	 * @param (int) $parent_id
	 * @return (array)
	 */
	function get_parent_linked_courses( $parent_id ) {

		global $wpdb;
		$table_name_course_link = $wpdb->prefix . 'ldap_course_link';
		$query                  = $wpdb->get_results(
			"SELECT child_id, course_id, order_id, link_date 
            FROM {$table_name_course_link} 
            WHERE parent_id = {$parent_id}"
		);

		return $query;
	}

	/**
	 *   Get all the vault courses of a parent
	 *
	 * @param (int) $parent_id
	 * @return (array)
	 */
	function get_parent_vault_courses( $parent_id ) {

		global $wpdb;
		$table_name_course = $wpdb->prefix . 'ldap_course_storage';
		$query             = $wpdb->get_results(
			"SELECT id, parent_id, course_id, order_id
            FROM {$table_name_course} 
            WHERE parent_id = {$parent_id}"
		);

		return $query;
	}

	function ldap_has_course_access( $parent_id, $course_id ) {
		global $wpdb;
		$table_name_course = $wpdb->prefix . 'ldap_course_storage';

		$exist = $wpdb->get_results( "SELECT parent_id, course_id FROM {$table_name_course} WHERE parent_id = {$parent_id} AND course_id = {$course_id} LIMIT 1", ARRAY_N );
		return ( ! empty( $exist ) ? true : false );
	}

	function message( $text = '', $color = 'red' ) {
		?>
		<p style="color: <?php echo $color; ?>; "><strong><?php echo $text; ?></strong></p>
		<?php
	}

}
