<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       immerseus.com
 * @since      1.0.0
 *
 * @package    Learndash_Access_For_Parents
 * @subpackage Learndash_Access_For_Parents/public/partials
 */
?>

<?php
if ( array_intersect( $allowed_roles, $current_user->roles ) ) {
	?>
<div class="learndash-wrapper">

	<div class="ld-profile-summary">
		<div class="ld-profile-card">
			<div class="ld-profile-avatar">
				<?php
				/**
				 * related to the CSS themes/ld30/assets/css/learndash.css
				 * .learndash-wrapper .ld-profile-summary .ld-profile-card .ld-profile-avatar
				 */
				echo wp_kses_post( get_avatar( $user_id, 150 ) );
				?>
			</div> <!--/.ld-profile-avatar-->
			<?php
			if ( ! empty( $current_user->user_lastname ) || ! empty( $current_user->user_firstname ) ) :
				?>
				<div class="ld-profile-heading">
					<?php echo esc_html( $current_user->user_firstname . ' ' . $current_user->user_lastname ); ?>
				</div>
			<?php endif; ?>
		</div> <!--/.ld-profile-card-->
	</div>

	<div class="ld-link-accout-wrapper">
		<form id="ld-submit-links" name="ld-submit-links" class="" method="POST"  >
			<h3><?php _e( 'Add additional children', 'learndash-access-for-parents' ); ?></h3>
			<p>
				<input type="email" name="link_child_email" required class="input link_child_input" placeholder="<?php esc_attr_e( 'Enter email address of child', 'learndash-access-for-parents' ); ?>" />
				<?php wp_nonce_field( 'ld-submit-links' ); ?>
				<input type="submit" name="ld-submit-links-button" class="ld-button ld-submit-links-button" value="<?php esc_attr_e( 'Add Child', 'learndash-access-for-parents' ); ?>" />
			</p>
		</form>
	</div>

	<?php if ( $allowed_to_create_accounts_without_email ) { ?>
	<div class="ld-link-accout-wrapper">
		<form id="ld-submit-no-email-account" name="ld-submit-no-email-account" class="" method="POST"  >
			<h3><?php esc_html_e( 'Add additional children without email', 'learndash-access-for-parents' ); ?></h3>
			<p>
				<label>
					<?php esc_html_e( 'First Name:', 'learndash-access-for-parents' ); ?>
					<input type="text" name="first_name" required class="input link_child_input" placeholder="<?php esc_attr_e( 'Enter the First name of the child', 'learndash-access-for-parents' ); ?>" />
				</label>
				<label>
					<?php esc_html_e( 'Last Name:', 'learndash-access-for-parents' ); ?>
					<input type="text" name="last_name" required class="input link_child_input" placeholder="<?php esc_attr_e( 'Enter the Last name of the child', 'learndash-access-for-parents' ); ?>" />
				</label>
				<label>
					<?php esc_html_e( 'Username:', 'learndash-access-for-parents' ); ?>
					<input type="text" name="username" required class="input link_child_input" placeholder="<?php esc_attr_e( 'Username will be used to log in', 'learndash-access-for-parents' ); ?>" />
				</label>
				<label>
					<?php esc_html_e( 'Password:', 'learndash-access-for-parents' ); ?>
					<input type="text" name="password" value="<?php echo wp_generate_password(); ?>" required class="input link_child_input" placeholder="<?php esc_attr_e( 'Enter the password to access the account', 'learndash-access-for-parents' ); ?>" autocomplete="off" />
				</label>
				<?php wp_nonce_field( 'ld-submit-no-email-account' ); ?>
				<input type="submit" name="ld-submit-no-email-account-button" class="ld-button ld-submit-no-email-account-button" value="<?php esc_attr_e( 'Add Child', 'learndash-access-for-parents' ); ?>" />
			</p>
		</form>
	</div>

	<?php } ?>

	<?php if ( ! empty( $students ) ) { ?>
	<div class="ld-link-accounts">
			<table class="spald-min-w-full spald-divide-y spald-divide-gray-200">
				<thead>
					<tr>
						<th class="spald-px-6 spald-py-3 spald-bg-gray-50 spald-text-left spald-text-xs spald-leading-4 spald-font-medium spald-text-gray-500 spald-uppercase spald-tracking-wider">
							<?php _e( 'Name', 'learndash-access-for-parents' ); ?>
						</th>
						<th class="spald-px-6 spald-py-3 spald-bg-gray-50 spald-text-left spald-text-xs spald-leading-4 spald-font-medium spald-text-gray-500 spald-uppercase spald-tracking-wider spald-text-center">
						<?php _e( 'Action', 'learndash-access-for-parents' ); ?>
						</th>
					</tr>
				</thead>
				<tbody class="spald-bg-white spald-divide-y spald-divide-gray-200">
					<?php
					foreach ( $students as $student ) {

						if ( $student->parent_id == get_current_user_id() ) {

							$studentDeatils = get_user_by( 'id', $student->child_id );
							?>
							<tr>
								<td class="spald-px-6 spald-py-4 ">
									<div class="spald-flex spald-items-center">
										<div class="spald-flex-shrink-0">
											<img class="userProfile spald-rounded-full" src="<?php echo get_avatar_url( $student->child_id ); ?>" alt="">
										</div>
										<div class="spald-ml-4">
											<div class="spald-text-sm spald-font-medium spald-text-gray-900">
												<?php echo $student->child_display_name; ?>
											</div>
											<div class="spald-text-sm spald-text-gray-500">
												<?php echo $studentDeatils->user_email; ?>
											</div>
											<?php if ( $student->is_child_confirmed ) { ?>
												<div class="spald-text-xs spald-text-green-500 spald-italic"><?php _e( '(Account Confirmed)', 'learndash-access-for-parents' ); ?></div>
											<?php } else { ?>
												<div class="spald-text-xs spald-text-gray-600 spald-italic spald-underline"><?php _e( '(Pending to Confirm)', 'learndash-access-for-parents' ); ?> -
													<form id="" class="spald-confirmation-form" name="ld-resend-confirmation-mail-form" method="POST"  >
														<input type="hidden" name="linked_child_id" value="<?php echo $student->child_id; ?>" />
														<?php wp_nonce_field( 'ld-resend-confirmation-mail' ); ?>
														<input type="submit" name="ld-resend-confirmation-mail-submit" class="spald-button spald-confirmation-button-link" value="<?php esc_attr_e( 'Resend Mail', 'learndash-access-for-parents' ); ?>">
													</form>
												</div>
											<?php } ?>
										</div>
									</div>
								</td>

								<td class="spald-px-6 spald-py-4 spald-align-middle spald-text-center spald-text-sm spald-font-medium">
									<form id="" name="ld-remove-links" class="ld-remove-links" method="POST"  >
										<input type="hidden" name="linked_child_id" value="<?php echo $student->child_id; ?>" />
										<?php wp_nonce_field( 'ld-remove-links' ); ?>
										<input type="submit" name="ld-delete-links-button" class="ldap-button ld-delete-links-button" value="<?php esc_attr_e( 'Unlink', 'learndash-access-for-parents' ); ?>">
									</form>
								</td>
							</tr>
							<?php
						}
					}
					?>
				</tbody>
			</table>
	</div>
	<?php } ?>

	<h3><?php _e( 'Available Courses that can be linked', 'learndash-access-for-parents' ); ?></h3>
	<?php
	$parent_courses       = learndash_user_get_enrolled_courses( $user_id, [], true );
	$parent_vault_courses = $this->get_parent_vault_courses( $user_id );

	if ( ( ! empty( $parent_vault_courses ) ) || ( ! empty( $parent_courses ) && is_array( $parent_courses ) ) ) {
		?>
		<div class="ldap-parent-courses">
				<table class="spald-min-w-full spald-divide-y spald-divide-gray-200">
					<thead>
						<tr>
							<th class="spald-px-6 spald-py-3 spald-bg-gray-50 spald-text-left spald-text-xs spald-leading-4 spald-font-medium spald-text-gray-500 spald-uppercase spald-tracking-wider spald-text-center">
								<?php _e( 'Course', 'learndash-access-for-parents' ); ?>
							</th>
							<th class="spald-px-6 spald-py-3 spald-bg-gray-50 spald-text-left spald-text-xs spald-leading-4 spald-font-medium spald-text-gray-500 spald-uppercase spald-tracking-wider spald-text-center">
							<?php _e( 'Action', 'learndash-access-for-parents' ); ?>
							</th>
						</tr>
					</thead>
					<tbody class="spald-bg-white spald-divide-y spald-divide-gray-200">
						<?php
						foreach ( $parent_courses as $course_id ) {
							$course          = $post = get_post( $course_id );
							$course_settings = learndash_get_setting( $course );
							if ( $course_settings['course_price_type'] != 'open' ) {
								$course_title = get_the_title( $course_id );
								?>
							<tr>
								<td data-course-id="<?php echo $course_id; ?>" class="spald-px-6 spald-py-4 spald-align-middle spald-text-sm spald-font-medium"><?php echo $course_title; ?></td>
								<td class="spald-px-6 spald-py-4 spald-align-middle spald-text-center spald-text-sm spald-font-medium">
									<button class="ldap-button ld-link-child-course" data-course-data="link-parent-course-wrapper-<?php echo $course_id; ?>"><?php _e( 'Expand', 'learndash-access-for-parents' ); ?></button>
								</td>
							</tr>
							<tr id="link-parent-course-wrapper-<?php echo $course_id; ?>" class="link-parent-course-wrapper">
								<td colspan="2" class="spald-px-6 spald-py-4 spald-align-middle spald-text-center spald-text-sm spald-font-medium">
									<?php if ( ! empty( $students ) ) { ?>
									<form id="" name="ldap-link-parent-course" class="ldap-link-parent-course" method="POST"  >
										<input type="hidden" name="course_id" value="<?php echo $course_id; ?>" />
										<?php wp_nonce_field( 'link-parent-course' ); ?>
										<label for=ldap-link-parent-course-child-<?php echo $course_id; ?>">
											<?php /* translators: %s: course title */ ?>
											<?php printf( __( '%s <strong>will be linked to </strong> ', 'learndash-access-for-parents' ), $course_title ); ?>
										</label>
										<select id="ldap-link-parent-course-child-<?php echo $course_id; ?>" name="ldap_link_parent_course_child">
										<option value=""><?php _e( '- Select User -', 'learndash-access-for-parents' ); ?></option>
										<?php
										foreach ( $students as $student ) {
											if ( $student->parent_id == get_current_user_id() ) {
												$child_detail = get_user_by( 'id', $student->child_id );
												$has_access   = sfwd_lms_has_access( $course_id, $student->child_id );
												echo "<option value='{$student->child_id}' " . ( $has_access ? 'disabled' : '' ) . ">{$child_detail->display_name}" . ( $has_access ? ' - Enrolled' : '' ) . '</option>';
											}
										}
										?>
										</select>
										<input type="submit" name="link-parent-course-button" class="ldap-button link-parent-course-button" value="Link">
									</form>
									<?php } else { ?>
										<p><?php _e( 'No available students to be linked.', 'learndash-access-for-parents' ); ?></p>
									<?php } ?>
								</td>
							</tr>
								<?php
							}
						}
						?>

						<?php
						foreach ( $parent_vault_courses as $vault ) {
							$course_id       = $vault->course_id;
							$course          = $post = get_post( $course_id );
							$course_settings = learndash_get_setting( $course );
							$order_id        = $vault->order_id;
							if ( $course_settings['course_price_type'] != 'open' ) {
								$course_title = get_the_title( $course_id );
								?>
							<tr>
								<td data-course-id="<?php echo $course_id; ?>" class="spald-px-6 spald-py-4 spald-align-middle spald-text-sm spald-font-medium"><?php echo $course_title; ?></td>
								<td class="px-6 py-4 align-middle text-center text-sm font-medium">
									<button class="ldap-button ld-link-child-course" data-course-data="link-parent-course-wrapper-<?php echo $course_id; ?>"><?php _e( 'Expand', 'learndash-access-for-parents' ); ?></button>
								</td>
							</tr>
							<tr id="link-parent-course-wrapper-<?php echo $course_id; ?>" class="link-parent-course-wrapper">
								<td colspan="2" class="spald-px-6 spald-py-4 spald-align-middle spald-text-center spald-text-sm spald-font-medium">
									<?php if ( ! empty( $students ) ) { ?>
									<form id="" name="ldap-link-parent-course" class="ldap-link-parent-course" method="POST"  >
										<input type="hidden" name="storage_id" value="<?php echo $vault->id; ?>" />
										<input type="hidden" name="course_id" value="<?php echo $course_id; ?>" />
										<input type="hidden" name="order_id" value="<?php echo $order_id; ?>" />
										<?php wp_nonce_field( 'link-parent-course' ); ?>
										<label for=ldap-link-parent-course-child-<?php echo $course_id; ?>"><?php printf( __( '%s <strong>will be linked to </strong> ', 'learndash-access-for-parents' ), $course_title ); ?></label>
										<select id="ldap-link-parent-course-child-<?php echo $course_id; ?>" name="ldap_link_parent_course_child">
										<option value=""><?php _e( '- Select User -', 'learndash-access-for-parents' ); ?></option>
										<?php
										foreach ( $students as $student ) {
											if ( $student->parent_id == get_current_user_id() && ! sfwd_lms_has_access( $course_id, $student->child_id ) ) {
												$child_detail = get_user_by( 'id', $student->child_id );
												echo "<option value='{$student->child_id}'>{$child_detail->display_name}</option>";
											}
										}
										?>
										</select>
										<input type="submit" name="link-parent-course-button" class="ldap-button link-parent-course-button" value="Link">
									</form>
									<?php } else { ?>
										<p><?php _e( 'No available students to be linked.', 'learndash-access-for-parents' ); ?></p>
									<?php } ?>
								</td>
							</tr>
							<?php } ?>
						<?php } ?>
					</tbody>
				</table>
		</div>
	<?php } else { ?>
		<p><?php _e( 'No available courses to be linked', 'learndash-access-for-parents' ); ?></p>
	<?php } ?>

	<?php
	$linked_courses = $this->get_parent_linked_courses( $user_id );
	if ( ! empty( $linked_courses ) && is_array( $linked_courses ) ) {
		?>
		<h3><?php _e( 'Linked Courses', 'learndash-access-for-parents' ); ?></h3>
		<div class="ld-parent-courses">
				<table class="spald-min-w-full spald-divide-y spald-divide-gray-200">
					<thead>
						<tr>
							<th class="spald-px-6 spald-py-3 spald-bg-gray-50 spald-text-left spald-text-xs spald-leading-4 spald-font-medium spald-text-gray-500 spald-uppercase spald-tracking-wider spald-text-center">
								<?php _e( 'Course', 'learndash-access-for-parents' ); ?>
							</th>
							<th class="spald-px-6 spald-py-3 spald-bg-gray-50 spald-text-left spald-text-xs spald-leading-4 spald-font-medium spald-text-gray-500 spald-uppercase spald-tracking-wider spald-text-center">
								<?php _e( 'Child', 'learndash-access-for-parents' ); ?>
							</th>
							<th class="spald-px-6 spald-py-3 spald-bg-gray-50 spald-text-left spald-text-xs spald-leading-4 spald-font-medium spald-text-gray-500 spald-uppercase spald-tracking-wider spald-text-center">
								<?php _e( 'Link Date', 'learndash-access-for-parents' ); ?>
							</th>
							<th class="spald-px-6 spald-py-3 spald-bg-gray-50 spald-text-left spald-text-xs spald-leading-4 spald-font-medium spald-text-gray-500 spald-uppercase spald-tracking-wider spald-text-center">
								<?php _e( 'Action', 'learndash-access-for-parents' ); ?>
							</th>
						</tr>
					</thead>
					<tbody class="spald-bg-white spald-divide-y spald-divide-gray-200">
						<?php
						foreach ( $linked_courses as $data ) {
							$course          = $post = get_post( $data->course_id );
							$course_settings = learndash_get_setting( $course );
							if ( sfwd_lms_has_access( $data->course_id, $data->child_id ) ) {
								?>
							<tr>
								<td data-course-id="<?php echo $data->course_id; ?>" class="spald-px-6 spald-py-4 spald-align-middle spald-text-sm spald-font-medium"><?php echo get_the_title( $data->course_id ); ?></td>
								<td class="spald-px-6 spald-py-4 spald-align-middle spald-text-sm spald-font-medium">
								<?php $child_detail = get_user_by( 'id', $data->child_id ); ?>
									<div class="spald-flex spald-items-center">
										<div class="spald-flex-shrink-0">
											<img class="userProfile spald-rounded-full" src="<?php echo get_avatar_url( $data->child_id ); ?>" alt="">
										</div>
										<div class="spald-ml-4">
											<div class="spald-text-sm spald-font-medium spald-text-gray-900">
												<?php echo $child_detail->display_name; ?>
											</div>
											<div class="spald-text-sm spald-text-gray-500">
												<?php echo $child_detail->user_email; ?>
											</div>
										</div>
									</div>
								</td>
								<td class="spald-px-6 spald-py-4 spald-align-middle spald-text-center spald-text-sm spald-font-medium">
									<?php
									$link_date = strtotime( $data->link_date );
									$link_date = date( 'M d, Y h:i A T', $link_date );
									echo $link_date;
									?>
								</td>
								<td class="spald-px-6 spald-py-4 spald-align-middle spald-text-center spald-text-sm spald-font-medium">
									<form id="" name="ld-unlink-course" class="ld-remove-links" method="POST"  >
										<input type="hidden" name="child_id" value="<?php echo $data->child_id; ?>" />
										<input type="hidden" name="course_id" value="<?php echo $data->course_id; ?>" />
										<input type="hidden" name="parent_id" value="<?php echo $user_id; ?>" />
										<input type="hidden" name="order_id" value="<?php echo $data->order_id; ?>" />

										<?php wp_nonce_field( 'ld-unlink-course' ); ?>
										<input type="submit" name="ld-unlink-course-button" class="ldap-button ld-delete-links-button" value="Unlink">
									</form>
								</td>
							</tr>
								<?php
							}
						}
						?>
					</tbody>
				</table>
		</div>
	<?php } ?>

</div>
	<?php
} else {
	?>
	<p><?php _e( 'Only parents can access this page', 'learndash-access-for-parents' ); ?></p>
	<?php
}

?>
