<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       immerseus.com
 * @since      1.0.0
 *
 * @package    Learndash_Access_For_Parents
 * @subpackage Learndash_Access_For_Parents/public/partials
 */
?>

<?php
	$expand_icon = '<span class="spald-ps__item__icon">
		<svg viewBox="0 0 32 32" xmlns="http://www.w3.org/2000/svg">
		<defs><style>.cls-1{fill:none;stroke:#000;stroke-linecap:round;stroke-linejoin:round;stroke-width:2px;}</style></defs>
		<g id="chevron-bottom"><line class="cls-1" x1="16" x2="7" y1="20.5" y2="11.5"/><line class="cls-1" x1="25" x2="16" y1="11.5" y2="20.5"/></g></svg>
	</span>';
?>


<div id="spald-pa-shortcode" class="spald-ps">
	<div class="spald-ps__header">
		<div class="spald-ps__header__title">
			<?php esc_html_e( 'Students', 'learndash-access-for-parents' ); ?>
		</div>
		<input id="spald-student-search-input" class="spald-ps__search" placeholder="<?php esc_attr_e( 'Search Student', 'learndash-access-for-parents' ); ?>"/>
	</div>
	<div class="spald-ps__container">
	<?php
	foreach ( $students as $student ) {
		$student_id  = $student->child_id;
		$student     = get_user_by( 'id', $student_id );
		$all_courses = ld_get_mycourses( $student_id );
		// <div class="spald-ps__item--is-active"></div> // for active items
		?>
		<div id="<?php echo esc_attr( $student_id ); ?>" class="spald-ps__item" data-name="<?php echo esc_attr( $student->display_name ); ?>" data-email="<?php echo esc_attr( $student->user_email ); ?>">
			<button class="spald-ps__item__button">
				<span>
					<img class="spald-ps__item__image" src="<?php echo esc_attr( get_avatar_url( $student_id ) ); ?>" alt="">
				</span>
				<span class="spald-ps__item__details">
					<span class="spald-ps__item__heading"><?php echo esc_html( $student->display_name ); ?></span>
					<span class="spald-ps__item__subheading"><?php echo esc_html( $student->user_email ); ?></span>
				</span>
				<?php echo $expand_icon; ?>
			</button>
			<div class="spald-ps__item__wrapper">
				<div class="spald-ps__header">
					<div class="spald-ps__header__title">
						<?php esc_html_e( 'Courses', 'learndash-access-for-parents' ); ?>
					</div>
					<input class="spald-ps__search" placeholder="<?php esc_attr_e( 'Search Course', 'learndash-access-for-parents' ); ?>"/>
				</div>
				<div class="spald-ps__container spald-ps__container--colored">
					<?php
					foreach ( $all_courses as $course_id ) {
						$progress = learndash_user_get_course_progress( $student_id, $course_id, 'summary' );
						$lessons  = learndash_course_get_lessons( $course_id );
						$lessons  = array_filter( $lessons, 'learndash_lesson_hasassignments' );

						$quiz_activities = $ldpa->ldpa_get_user_quiz_activities( $student_id, $course_id );

						?>
						<div
							id="<?php echo esc_attr( $student_id ) . '-' . esc_attr( $course_id ); ?>"
							class="spald-ps__item"
							data-course-name="<?php echo esc_attr( get_the_title( $course_id ) ); ?>"
							data-course-status="<?php echo esc_attr( learndash_course_status( $course_id, $student_id ) ); ?>"
						>
							<button class="spald-ps__item__button">
								<span class="spald-ps__item__details">
									<span class="spald-ps__item__heading">
										<?php
										echo esc_html(
											get_the_title( $course_id )
										);
										?>
									</span>
									<span class="spald-ps__item__subheading">
										<?php echo esc_html( learndash_course_status( $course_id, $student_id ) ); ?>
									</span>
								</span>
								<span class="spald-ps__item__details">
									<span class="spald-ps__item__subheading">
										<?php
										echo sprintf( __( 'Progress: Completed %1$d of %2$d Total Steps.', 'learndash-access-for-parents' ), $progress['completed'], $progress['total'] );
										?>
									</span>
								</span>
								<?php echo $expand_icon; ?>
							</button>
							<div class="spald-ps__item__wrapper">
								<div class="spald-ps__container">
									<div
										id="<?php echo esc_attr( $student_id ) . '-' . esc_attr( $course_id ) . '-assignments'; ?>"
										class="spald-ps__item"
									>
										<button
											class="spald-ps__item__button spald-ps__item__button--small"
											<?php
											if ( 0 === count( $lessons ) ) {
												?>
												disabled 
												<?php
											}
											?>
										>
											<span class="spald-ps__item__details">
												<span class="spald-ps__item__heading">
													<?php esc_html_e( 'Assignments', 'learndash-access-for-parents' ); ?>
												</span>
											</span>
											<span class="spald-ps__item__details">
												<?php if ( 0 === count( $lessons ) ) { ?>
												<span class="spald-ps__item__subheading">
													<?php esc_html_e( 'No assignments required.', 'learndash-access-for-parents' ); ?>
												</span>
												<?php } ?>
											</span>
											<?php if ( 0 !== count( $lessons ) ) { ?>
												<?php echo $expand_icon; ?>
											<?php } else { ?>
												<span></span>
											<?php } ?>
										</button>
										<div class="spald-ps__item__wrapper">
											<div class="spald-ps__container">
												<?php
												foreach ( $lessons as $key => $lesson ) {
													$assignment = learndash_get_user_assignments( $lesson->ID, $student_id, $course_id );
													?>

													<?php if ( 0 === $key ) { ?>
														<div class="spald-ps__data__wrapper spald-ps__data__wrapper--assignments">
															<div class="spald-ps__data__title">
																<?php esc_html_e( 'Attached to Lesson', 'learndash-access-for-parents' ); ?>
															</div>
															<div class="spald-ps__data__title">
																<?php esc_html_e( 'Status', 'learndash-access-for-parents' ); ?>
															</div>
														</div>
													<?php } ?>

													<div class="spald-ps__data__wrapper spald-ps__data__wrapper--assignments">
														<div class="spald-ps__data__text"><?php echo esc_html( $lesson->post_title ); ?></div>
														<div class="spald-ps__data__text">
															<?php
															( ! empty( $assignment ) )
																? esc_html_e( 'Submitted', 'learndash-access-for-parents' )
																: esc_html_e( 'Not Submitted', 'learndash-access-for-parents' );
															?>
														</div>
													</div>
													<?php
												}
												?>
											</div>
										</div>
									</div>

									<div
										id="<?php echo esc_attr( $student_id ) . '-' . esc_attr( $course_id ) . '-quiz-activity'; ?>"
										class="spald-ps__item"
									>
										<button
											class="spald-ps__item__button spald-ps__item__button--small"
											<?php
											if ( 0 === count( $quiz_activities ) ) {
												?>
												disabled 
												<?php
											}
											?>
											>
											<span class="spald-ps__item__details">
												<span class="spald-ps__item__heading">
													<?php esc_html_e( 'Quiz Activity', 'learndash-access-for-parents' ); ?>
												</span>
											</span>
											<span class="spald-ps__item__details">
												<?php
												if ( 0 === count( $quiz_activities ) ) {
													?>
													<span class="spald-ps__item__subheading">
														<?php esc_html_e( 'No current Quiz activity.', 'learndash-access-for-parents' ); ?>
													</span>
													<?php
												}
												?>
											</span>
											<?php if ( 0 !== count( $quiz_activities ) ) { ?>
												<?php echo $expand_icon; ?>
											<?php } else { ?>
												<span></span>
											<?php } ?>
										</button>
										<div class="spald-ps__item__wrapper">
											<div class="spald-ps__container">
												<?php
												$quizzes = [];

												foreach ( $quiz_activities as $activity ) {
													if ( ! in_array( $activity['post_id'], $quizzes, true ) ) {
														$quizzes[] = $activity['post_id'];
													}
												}

												foreach ( $quizzes as $key => $quiz_id ) {
													$quiz               = get_post( $quiz_id );
													$quiz_progress      = array_values( learndash_user_get_quiz_progress( $student_id, $quiz_id, $course_id ) );
													$scores             = array_column( array_values( $quiz_progress ), 'points' );
													$total_score        = max( array_column( array_values( $quiz_progress ), 'total_points' ) );
													$highest_score      = max( $scores );
													$count              = learndash_get_user_quiz_attempts_count( $student_id, $quiz_id );
													$certificate_result = $ldpa->ldpa_get_user_quiz_certificate_status( $quiz_id, $student_id );
													?>

													<div class="spald-ps__data__wrapper spald-ps__data__wrapper--quizzes">
														<div class="spald-ps__data__title">
															<?php esc_html_e( 'Quiz', 'learndash-access-for-parents' ); ?>
														</div>
														<div class="spald-ps__data__title">
															<?php esc_html_e( 'Attempts', 'learndash-access-for-parents' ); ?>
														</div>
														<div class="spald-ps__data__title">
															<?php esc_html_e( 'Highest Score', 'learndash-access-for-parents' ); ?>
														</div>
														<div class="spald-ps__data__title">
															<?php esc_html_e( 'Total Points', 'learndash-access-for-parents' ); ?>
														</div>
														<div class="spald-ps__data__title">
															<?php esc_html_e( 'Certificate', 'learndash-access-for-parents' ); ?>
														</div>
													</div>

													<div class="spald-ps__data__wrapper spald-ps__data__wrapper--quizzes">
														<div class="spald-ps__data__text"><?php echo esc_html( $quiz->post_title ); ?></div>
														<div class="spald-ps__data__text"><?php echo esc_html( $count ); ?></div>
														<div class="spald-ps__data__text"><?php echo esc_html( $highest_score ); ?></div>
														<div class="spald-ps__data__text"><?php echo esc_html( $total_score ); ?></div>
														<div class="spald-ps__data__text"><?php echo esc_html( $certificate_result ); ?></div>
													</div>

													<div class="spald-ps__container spald-ps__container--quiz-attempts">
														<?php
														foreach ( $quiz_progress as $key => $progress ) {
															?>

																<?php if ( 0 === $key ) { ?>
																	<div class="spald-ps__data__wrapper spald-ps__data__wrapper--quiz-progress">
																		<div class="spald-ps__data__title">
																			<?php esc_html_e( 'Attempt', 'learndash-access-for-parents' ); ?>
																		</div>
																		<div class="spald-ps__data__title">
																			<?php esc_html_e( 'Score', 'learndash-access-for-parents' ); ?>
																		</div>
																		<div class="spald-ps__data__title">
																			<?php esc_html_e( 'Time spent (secs)', 'learndash-access-for-parents' ); ?>
																		</div>
																	</div>
																<?php } ?>

																<div class="spald-ps__data__wrapper spald-ps__data__wrapper--quiz-progress">
																	<div class="spald-ps__data__text"><?php echo esc_html( '#' . ( $key + 1 ) ); ?></div>
																	<div class="spald-ps__data__text"><?php echo esc_html( $progress['score'] ); ?></div>
																	<div class="spald-ps__data__text"><?php echo esc_html( $progress['timespent'] ); ?></div>
																</div>

															<?php
														}
														?>
													</div>

													<?php
												}
												?>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
						<?php
					}
					?>
				</div>
			</div>
		</div>
		<?php
	}
	?>
	</div>
</div>
